% --- Outputs from this function are returned to the command line.
function varargout = Ultrasound_Analyse_OutputFcn(hObject, eventdata, handles)
    % varargout  cell array for returning output args (see VARARGOUT);
    % hObject    handle to figure
    % eventdata  reserved - to be defined in a future version of MATLAB
    % handles    structure with handles and user data (see GUIDATA)

    % Get default command line output from handles structure
    %varargout{1} = handles.output;
    varargout{1} = [];
end